select 
    quote(@entry_type) as entry_type,
    quote(@dbsource) as database_name,
    quote(replace(n.name,'"','')) as db_id,
    quote(concat(@dbname, "_", f.id)) as db_version, # using to build unicity constraint over all documents (concat of entry_type, database_name, db_id and db_version Solr fields)
    quote(concat(replace(
    				replace(n.name,'"',''), -- remove double quotes
    				'\'', '\' '), -- replace pattern "'," which is used as delimiter later
            	' is a ',
                t.tag,
                ' of ',
				@taxon,
				' located between positions ',
                f.start,
                ' and ',
                f.end,
                ' on ',
                ll.seqname,
                ' and which properties are ',
                props.attributes)) as description,
    quote(
    CASE WHEN n.name LIKE '%:%' THEN concat(@url_base,replace(replace(n.name,'"',''),':','%3A'))
   	 WHEN n.name LIKE '%#%' THEN concat(@url_base,replace(replace(n.name,'"',''),'#','%23'))
    ELSE concat(@url_base,replace(n.name,'"','')) 
    END) as url,
    quote(@taxon) as species,
    quote("") as xref,
    quote(t.tag) as feature_type,
    quote("") as sequence_id,
    quote("") as sequence_version,
    f.start as start_position,
    f.end as end_position,
    quote("") as map,
    quote("") as map_position,
    quote("") as authority,
    quote("") as trait,
    quote("") as trait_id,
    quote("") as environment,
    quote("") as environment_id,
    quote("") as statistic,
    quote("") as unit,
    quote("") as genotype,
    quote("") as experiment_type
from 
	(
		select f1.id as fid,
		group_concat(
			concat_ws('=',al.tag,
					replace(a.attribute_value, '"', '')
			)
		) as attributes -- remove all double quotes which are used as field delimiter 
		from feature f1
		join attribute a on a.id = f1.id
		join attributelist al on al.id=a.attribute_id
		group by fid
	) as props
join feature f on f.id = props.fid
join name n on n.id=f.id
join typelist t on t.id=f.typeid
join locationlist ll on ll.id=f.seqid
where n.display_name=1 -- same as currently indexed in GnpIS quick search, cf l. 23 in gnpis-portal/core/src/main/java/fr/inra/genome/model/biodbseqfeature/Feature.hbm.xml
order by f.id
;
